from setuptools import setup

setup(name='pdistributions',
      version='0.1',
      description='Gaussian distributions1',
      packages=['pdistributions'],
      author = 'Muhammad Liman Dahiru',
      author_email = 'mlimand76@gmail.com',
      zip_safe=False)
